sqlglot.optimizer API documentation

Edit on GitHub

# sqlglot.optimizer

View Source

     1# ruff: noqa: F401
     2
     3from sqlglot.optimizer.optimizer import RULES as RULES, optimize as optimize
     4from sqlglot.optimizer.scope import (
     5    Scope as Scope,
     6    build_scope as build_scope,
     7    find_all_in_scope as find_all_in_scope,
     8    find_in_scope as find_in_scope,
     9    traverse_scope as traverse_scope,
    10    walk_in_scope as walk_in_scope,
    11)